==> tamarack-0.0.3.tar.gz: tamarack-0.0.3/tamarack/static/js-out/tamarack-main.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.string.StringBuffer', 'goog.array']);
goog.addDependency("../cljs/reader.js", ['cljs.reader'], ['goog.string', 'cljs.core']);
goog.addDependency("../tamarack/xhr.js", ['tamarack.xhr'], ['goog.net.XhrIo', 'cljs.core', 'goog.events.EventType', 'cljs.reader', 'goog.events']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../tamarack/util.js", ['tamarack.util'], ['cljs.core', 'clojure.string']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../sablono/util.js", ['sablono.util'], ['goog.Uri', 'cljs.core', 'clojure.set', 'clojure.string']);
goog.addDependency("../sablono/interpreter.js", ['sablono.interpreter'], ['sablono.util', 'cljs.core', 'clojure.string']);
goog.addDependency("../clojure/walk.js", ['clojure.walk'], ['cljs.core']);
goog.addDependency("../sablono/core.js", ['sablono.core'], ['goog.dom', 'sablono.util', 'cljs.core', 'sablono.interpreter', 'clojure.string', 'clojure.walk']);
goog.addDependency("../om/dom.js", ['om.dom'], ['cljs.core']);
goog.addDependency("../om/core.js", ['om.core'], ['cljs.core', 'om.dom', 'goog.ui.IdGenerator']);
goog.addDependency("../tamarack/history.js", ['tamarack.history'], ['cljs.core', 'goog.history.EventType', 'goog.History', 'goog.events']);
goog.addDependency("../tamarack/state.js", ['tamarack.state'], ['cljs.core', 'tamarack.util', 'tamarack.xhr', 'om.core', 'clojure.string']);
goog.addDependency("../secretary/core.js", ['secretary.core'], ['cljs.core', 'clojure.string', 'clojure.walk']);
goog.addDependency("../tamarack/routes.js", ['tamarack.routes'], ['tamarack.history', 'tamarack.state', 'cljs.core', 'goog.History', 'secretary.core', 'clojure.string']);
goog.addDependency("../tamarack/components/agg_table.js", ['tamarack.components.agg_table'], ['cljs.core', 'tamarack.util', 'sablono.core', 'tamarack.xhr', 'om.core', 'clojure.string', 'tamarack.routes']);
goog.addDependency("../tamarack/canvas.js", ['tamarack.canvas'], ['cljs.core']);
goog.addDependency("../tamarack/chart.js", ['tamarack.chart'], ['goog.string', 'cljs.core', 'tamarack.util', 'goog.string.format', 'tamarack.canvas', 'clojure.string']);
goog.addDependency("../tamarack/components/chart.js", ['tamarack.components.chart'], ['cljs.core', 'tamarack.util', 'tamarack.chart', 'sablono.core', 'tamarack.xhr', 'tamarack.canvas', 'om.core']);
goog.addDependency("../tamarack/components/debug.js", ['tamarack.components.debug'], ['cljs.core', 'sablono.core', 'om.core']);
goog.addDependency("../tamarack/pages/all_apps.js", ['tamarack.pages.all_apps'], ['cljs.core', 'sablono.core', 'tamarack.xhr', 'om.core', 'clojure.string', 'tamarack.routes']);
goog.addDependency("../tamarack/components/sidebar.js", ['tamarack.components.sidebar'], ['cljs.core', 'sablono.core', 'om.core', 'clojure.string']);
goog.addDependency("../tamarack/pages/app_endpoint_overview.js", ['tamarack.pages.app_endpoint_overview'], ['cljs.core', 'sablono.core', 'om.core', 'clojure.string', 'tamarack.components.chart']);
goog.addDependency("../tamarack/pages/app_dashboard.js", ['tamarack.pages.app_dashboard'], ['tamarack.components.agg_table', 'cljs.core', 'tamarack.util', 'sablono.core', 'om.core', 'clojure.string', 'tamarack.components.chart']);
goog.addDependency("../tamarack/pages/main.js", ['tamarack.pages.main'], ['tamarack.pages.all_apps', 'tamarack.pages.app_endpoint_overview', 'tamarack.state', 'cljs.core', 'om.core', 'tamarack.pages.app_dashboard']);
goog.addDependency("../tamarack/components/timeslice.js", ['tamarack.components.timeslice'], ['tamarack.state', 'cljs.core', 'goog.date.duration', 'tamarack.util', 'sablono.core', 'om.core', 'tamarack.routes']);
goog.addDependency("../tamarack/view.js", ['tamarack.view'], ['tamarack.components.debug', 'tamarack.state', 'cljs.core', 'tamarack.util', 'tamarack.components.sidebar', 'om.core', 'tamarack.pages.main', 'tamarack.components.timeslice']);
goog.addDependency("../tamarack/core.js", ['tamarack.core'], ['tamarack.history', 'tamarack.view', 'tamarack.state', 'cljs.core', 'goog.history.EventType', 'tamarack.util', 'goog.History', 'secretary.core', 'goog.events', 'tamarack.routes']);

==> tamarack-0.0.5.tar.gz: tamarack-0.0.5/tamarack/static/js-out/tamarack-main.js <==
goog.addDependency("base.js", ['goog'], []);
goog.addDependency("../cljs/core.js", ['cljs.core'], ['goog.string', 'goog.object', 'goog.string.StringBuffer', 'goog.array']);
goog.addDependency("../cljs/reader.js", ['cljs.reader'], ['goog.string', 'cljs.core']);
goog.addDependency("../tamarack/xhr.js", ['tamarack.xhr'], ['goog.net.XhrIo', 'cljs.core', 'goog.events.EventType', 'cljs.reader', 'goog.events']);
goog.addDependency("../clojure/string.js", ['clojure.string'], ['goog.string', 'cljs.core', 'goog.string.StringBuffer']);
goog.addDependency("../tamarack/util.js", ['tamarack.util'], ['cljs.core', 'clojure.string']);
goog.addDependency("../clojure/set.js", ['clojure.set'], ['cljs.core']);
goog.addDependency("../clojure/walk.js", ['clojure.walk'], ['cljs.core']);
goog.addDependency("../sablono/util.js", ['sablono.util'], ['goog.Uri', 'cljs.core', 'clojure.set', 'clojure.string', 'clojure.walk']);
goog.addDependency("../sablono/interpreter.js", ['sablono.interpreter'], ['sablono.util', 'cljs.core', 'clojure.string']);
goog.addDependency("../sablono/core.js", ['sablono.core'], ['goog.dom', 'sablono.util', 'cljs.core', 'sablono.interpreter', 'clojure.string', 'clojure.walk']);
goog.addDependency("../om/dom.js", ['om.dom'], ['cljs.core']);
goog.addDependency("../om/core.js", ['om.core'], ['cljs.core', 'om.dom', 'goog.ui.IdGenerator']);
goog.addDependency("../tamarack/history.js", ['tamarack.history'], ['cljs.core', 'goog.history.EventType', 'goog.History', 'goog.events']);
goog.addDependency("../tamarack/state.js", ['tamarack.state'], ['cljs.core', 'tamarack.util', 'tamarack.xhr', 'om.core', 'clojure.string']);
goog.addDependency("../secretary/core.js", ['secretary.core'], ['cljs.core', 'clojure.string', 'clojure.walk']);
goog.addDependency("../tamarack/routes.js", ['tamarack.routes'], ['tamarack.history', 'tamarack.state', 'cljs.core', 'goog.History', 'secretary.core', 'clojure.string']);
goog.addDependency("../tamarack/components/agg_table.js", ['tamarack.components.agg_table'], ['cljs.core', 'tamarack.util', 'sablono.core', 'tamarack.xhr', 'om.core', 'clojure.string', 'tamarack.routes']);
goog.addDependency("../tamarack/canvas.js", ['tamarack.canvas'], ['cljs.core']);
goog.addDependency("../tamarack/chart.js", ['tamarack.chart'], ['goog.string', 'cljs.core', 'tamarack.util', 'goog.string.format', 'tamarack.canvas', 'clojure.string']);
goog.addDependency("../tamarack/components/chart.js", ['tamarack.components.chart'], ['cljs.core', 'tamarack.util', 'tamarack.chart', 'sablono.core', 'tamarack.xhr', 'tamarack.canvas', 'om.core']);
goog.addDependency("../tamarack/components/debug.js", ['tamarack.components.debug'], ['cljs.core', 'sablono.core', 'om.core']);
goog.addDependency("../tamarack/pages/all_apps.js", ['tamarack.pages.all_apps'], ['cljs.core', 'sablono.core', 'tamarack.xhr', 'om.core', 'clojure.string', 'tamarack.routes']);
goog.addDependency("../tamarack/components/sidebar.js", ['tamarack.components.sidebar'], ['cljs.core', 'sablono.core', 'om.core', 'clojure.string']);
goog.addDependency("../tamarack/pages/app_endpoint_overview.js", ['tamarack.pages.app_endpoint_overview'], ['cljs.core', 'sablono.core', 'om.core', 'clojure.string', 'tamarack.components.chart']);
goog.addDependency("../tamarack/pages/app_dashboard.js", ['tamarack.pages.app_dashboard'], ['tamarack.components.agg_table', 'cljs.core', 'tamarack.util', 'sablono.core', 'om.core', 'clojure.string', 'tamarack.components.chart']);
goog.addDependency("../tamarack/pages/main.js", ['tamarack.pages.main'], ['tamarack.pages.all_apps', 'tamarack.pages.app_endpoint_overview', 'tamarack.state', 'cljs.core', 'om.core', 'tamarack.pages.app_dashboard']);
goog.addDependency("../tamarack/components/timeslice.js", ['tamarack.components.timeslice'], ['tamarack.state', 'cljs.core', 'goog.date.duration', 'tamarack.util', 'sablono.core', 'om.core', 'tamarack.routes']);
goog.addDependency("../tamarack/view.js", ['tamarack.view'], ['tamarack.components.debug', 'tamarack.state', 'cljs.core', 'tamarack.util', 'tamarack.components.sidebar', 'om.core', 'tamarack.pages.main', 'tamarack.components.timeslice']);
goog.addDependency("../tamarack/core.js", ['tamarack.core'], ['tamarack.history', 'tamarack.view', 'tamarack.state', 'cljs.core', 'goog.history.EventType', 'tamarack.util', 'goog.History', 'secretary.core', 'goog.events', 'tamarack.routes']);
